@@ -551,36 +551,32 @@ impl<Data: Send + Sync + 'static> Fetcher<Data> {
                 let extra = extra.clone();
 
                 async move {
-                    tokio::spawn(async move {
-                        let range = range::to_string(range_start, Some(range_end));
+                    let range = range::to_string(range_start, Some(range_end));
 
-                        fetcher.send(|| {
-                            (
-                                to.clone(),
-                                extra.clone(),
-                                FetchEvent::PartFetching(partn as u64),
-                            )
-                        });
+                    fetcher.send(|| {
+                        (
+                            to.clone(),
+                            extra.clone(),
+                            FetchEvent::PartFetching(partn as u64),
+                        )
+                    });
 
-                        let request = Request::get(&*uri).header("range", range.as_str());
+                    let request = Request::get(&*uri).header("range", range.as_str());
 
-                        let result = fetcher
-                            .get(
-                                &mut modified,
-                                request,
-                                part_path.into(),
-                                Some(range_end - range_start),
-                                0,
-                                extra.clone(),
-                            )
-                            .await;
+                    let result = fetcher
+                        .get(
+                            &mut modified,
+                            request,
+                            part_path.into(),
+                            Some(range_end - range_start),
+                            0,
+                            extra.clone(),
+                        )
+                        .await;
 
-                        fetcher.send(|| (to, extra.clone(), FetchEvent::PartFetched(partn as u64)));
+                    fetcher.send(|| (to, extra.clone(), FetchEvent::PartFetched(partn as u64)));
 
-                        result
-                    })
-                    .await
-                    .expect("failed to join tokio handle")
+                    result
                 }
             })
             // Ensure that only this many connections are happenning concurrently at a
